import numpy as np

def calc_motion(VI, amax):
    """
    Braking of a car from V = VI to rest with a maximum deceleration of amax 
    assuming a quadratic deceleration

    Args:
        VI (float): Initial velocity
        amax (float): Maximum acceleration (should be negative since this is a deceleration)

    Returns:
        x (numpy float array): position (distance travelled)
        V (numpy float array): velocity
        a (numpy float array): acceleration
        t (numpy float array): time

    """

    tb = -1.5*VI/amax # Time to come to rest

    N = 1001 # number of points
    t = np.linspace(0,tb,N)

    tt = t/tb

    x = VI*t + 4*amax*tb**2*((1/6)*tt**3 - (1/12)*tt**4)
    V = VI + 4*amax*tb*((1/2)*tt**2 - (1/3)*tt**3)
    a = 4*amax*tt*(1-tt)

    return x, V, a, t