################################################################################
# Model cooling of coffee in a cup with a simple lumped model
#
#    mc cc dTc/dt = h A (Tout - Tc)
#
# where: mc = mass of coffee in cup
#        cc = heat capacity of coffee
#        Tc = temperature of coffee
#      Tout = temperature of environment
#         h = heat transfer coefficient
#         A = surface area of coffee cup (including upper surface)
#
    
import coffee_model as cm
import matplotlib.pyplot as plt

p = {}
p['mc'] = 0.35 # kg
p['cc'] = 4200.0 # J / (kg C)
p['h']  = 5.0 # W/(m^2 C)
p['A']  = 0.04 # m^2
p['Tout'] = 25.0 # C
        
TcI = 85.0 # Initial temperature of coffee (C)
tF = 700.0 # final time to simulate to (min)
dt = 0.01 # time increment to give solutions at (min)
    
t, Tc = cm.solve_coffee(TcI, tF, dt, p)
    
plt.plot(t,Tc,label='$25^o$ C day')
plt.xlabel('t (min)')
plt.ylabel('$T_c$ (C)')
plt.title('Coffee temperature vs. time')
plt.grid(True)

# fig, axs = plt.subplots()
# axs.plot(t,Tc)
# axs.set_xlabel('t (min)')
# axs.set_ylabel('$T_c$ (C)')
# axs.set_title('Coffee temperature vs. time')
# axs.grid(True)

p['Tout'] = 5.0 # C
t_cold, Tc_cold = cm.solve_coffee(TcI, tF, dt, p)

plt.plot(t_cold,Tc_cold,label='$5^o$ C day')
plt.legend()

# axs.plot(t_cold,Tc_cold)
# axs.legend()