################################################################################
# Model predator-prey population dynamics
#
#    dr/dt =  a r - b r f
#    df/dt = -m f + c b r f 
#
# where: r  = population of prey (e.g. number of rabbits)
#        f  = population of predator (e.g. number of foxes)
#        a  = birth rate of prey per capita
#        m  = mortality rate of predator per capita
#        b  = predation rate per prey x predator
#        c  = frequency at which predation results prey
#
    
import predprey_model as pm
import matplotlib.pyplot as plt

p = {}
p['a'] = 2.0
p['b'] = 0.01
p['c'] = 0.1
p['m'] = 1.0

rI = 500
fI = 100
uI = [rI, fI]        
tF = 10.0 # final time to simulate to (month)
dt = 0.05 # time increment to give solutions at (s)
    
t, r, f = pm.solve_predprey(uI, tF, dt, p)
    
plt.plot(t,r,label='rabbit')
plt.plot(t,f,label='fox')
plt.xlabel('t (months)')
plt.ylabel('population size')
plt.grid(True)
plt.legend()
